@@ -1,4 +1,6 @@
 package POE::Component::Server::POP3;
+$POE::Component::Server::POP3::VERSION = '0.12';
+#ABSTRACT: A POE framework for authoring POP3 servers
 
 use strict;
 use warnings;
@@ -6,16 +8,13 @@ use POE qw(Wheel::SocketFactory Wheel::ReadWrite Filter::Line);
 use base qw(POE::Component::Pluggable);
 use POE::Component::Pluggable::Constants qw(:ALL);
 use Socket;
-use vars qw($VERSION);
-
-$VERSION = '0.10';
 
 sub spawn {
   my $package = shift;
   my %opts = @_;
   $opts{lc $_} = delete $opts{$_} for keys %opts;
   my $options = delete $opts{options};
-  $opts{version} = join('-', __PACKAGE__, $VERSION ) unless $opts{version};
+  $opts{version} = join('-', __PACKAGE__, $POE::Component::Server::POP3::VERSION ) unless $opts{version};
   $opts{handle_connects} = 1 unless defined $opts{handle_connects} and !$opts{handle_connects};
   $opts{hostname} = 'localhost' unless defined $opts{hostname};
   my $self = bless \%opts, $package;
@@ -47,7 +46,7 @@ sub getsockname {
 sub _conn_exists {
   my ($self,$wheel_id) = @_;
   return 0 unless $wheel_id and defined $self->{clients}->{ $wheel_id };
-  return 1; 
+  return 1;
 }
 
 sub _valid_cmd {
@@ -68,7 +67,7 @@ sub _start {
   $self->{session_id} = $_[SESSION]->ID();
   if ( $self->{alias} ) {
 	$kernel->alias_set( $self->{alias} );
-  } 
+  }
   else {
 	$kernel->refcount_increment( $self->{session_id} => __PACKAGE__ );
   }
@@ -114,11 +113,11 @@ sub _accept_client {
   );
 
   return unless $wheel;
-  
+
   my $id = $wheel->ID();
-  $self->{clients}->{ $id } = 
-  { 
-				wheel    => $wheel, 
+  $self->{clients}->{ $id } =
+  {
+				wheel    => $wheel,
 				peeraddr => $peeraddr,
 				peerport => $peerport,
 				sockaddr => $sockaddr,
@@ -258,7 +257,7 @@ sub _unregister_sessions {
   foreach my $session_id ( keys %{ $self->{sessions} } ) {
      if (--$self->{sessions}->{$session_id}->{refcnt} <= 0) {
         delete $self->{sessions}->{$session_id};
-	$poe_kernel->refcount_decrement($session_id, __PACKAGE__) 
+	$poe_kernel->refcount_decrement($session_id, __PACKAGE__)
 		unless ( $session_id eq $pop3d_id );
      }
   }
@@ -339,10 +338,18 @@ sub POP3D_connection {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 POE::Component::Server::POP3 - A POE framework for authoring POP3 servers
 
+=head1 VERSION
+
+version 0.12
+
 =head1 SYNOPSIS
 
   # A simple POP3 Server that demonstrates functionality
@@ -474,6 +481,8 @@ may register to receive. The POP3 poco also handles sending output to applicable
 
 One may either interface with the component via the POE API or via L<POE::Component::Pluggable> plugins.
 
+=for Pod::Coverage POP3D_connection
+
 =head1 CONSTRUCTOR
 
 =over
@@ -633,7 +642,7 @@ with the following line:
 
 The return values have the following significance:
 
-=over 
+=over
 
 =item C<POP3D_EAT_NONE>
 
@@ -804,20 +813,21 @@ The basic anatomy of a plugin is:
                 return POP3D_EAT_NONE;
         }
 
-=head1 AUTHOR
-
-Chris C<BinGOs> Williams <chris@bingosnet.co.uk>
-
-=head1 LICENSE
-
-Copyright E<copy> Chris Williams
-
-This module may be used, modified, and distributed under the same terms as Perl itself. Please see the license that came with your Perl distribution for details.
-
 =head1 SEE ALSO
 
 L<POE::Component::Pluggable>
 
 RFC 1939 L<http://www.faqs.org/rfcs/rfc1939.html>
 
+=head1 AUTHOR
+
+Chris Williams <chris@bingosnet.co.uk>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by Chris Williams.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
