@@ -1,4 +1,6 @@
 package POE::Component::Server::POP3::Constants;
+$POE::Component::Server::POP3::Constants::VERSION = '0.12';
+#ABSTRACT: importable constants for POE::Component::Server::POP3 plugins.
 
 require Exporter;
 @ISA = qw( Exporter );
@@ -7,9 +9,6 @@ Exporter::export_ok_tags( 'ALL' );
 
 use strict;
 use warnings;
-use vars qw($VERSION);
-
-$VERSION = '0.10';
 
 # Our constants
 sub POP3D_EAT_NONE	() { 1 }
@@ -17,13 +16,22 @@ sub POP3D_EAT_CLIENT	() { 2 }
 sub POP3D_EAT_PLUGIN	() { 3 }
 sub POP3D_EAT_ALL	() { 4 }
 
-1;
+qq[POP3 will eat itself];
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 POE::Component::Server::POP3::Constants - importable constants for POE::Component::Server::POP3 plugins.
 
+=head1 VERSION
+
+version 0.12
+
 =head1 SYNOPSIS
 
   use POE::Component::Server::POP3::Constants qw(:ALL);
@@ -54,18 +62,19 @@ Value: 4
 
 =back
 
-=head1 MAINTAINER
-
-Chris 'BinGOs' Williams <chris@bingosnet.co.uk>
-
-=head1 LICENSE
-
-Copyright E<copy> Chris Williams
-
-This module may be used, modified, and distributed under the same terms as Perl itself. Please see the license that came with your Perl distribution for details.
-
 =head1 SEE ALSO
 
 L<POE::Component::Server::POP3>
 
+=head1 AUTHOR
+
+Chris Williams <chris@bingosnet.co.uk>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by Chris Williams.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
